summaryrefslogtreecommitdiffhomepage
path: root/tools/checkescape
diff options
context:
space:
mode:
authorAdin Scannell <ascannell@google.com>2020-10-08 11:22:15 -0700
committergVisor bot <gvisor-bot@google.com>2020-10-08 11:24:21 -0700
commit5124ce579d34079d2aefd45b486e0127ed6c2917 (patch)
tree93b9b14a89f741c066a960a0360c19832335806b /tools/checkescape
parent06200cb5cfd44dbd3edc221fa3f6c1a716a8c4c6 (diff)
Minor nogo cleanup.
PiperOrigin-RevId: 336126583
Diffstat (limited to 'tools/checkescape')
-rw-r--r--tools/checkescape/checkescape.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/checkescape/checkescape.go b/tools/checkescape/checkescape.go
index f5bba9980..523a42692 100644
--- a/tools/checkescape/checkescape.go
+++ b/tools/checkescape/checkescape.go
@@ -102,8 +102,8 @@ var (
// This may be set instead of Binary.
Reader io.Reader
- // Tool is the tool used to dump a binary.
- tool = flag.String("dump_tool", "", "tool used to dump a binary")
+ // objdumpTool is the tool used to dump a binary.
+ objdumpTool = flag.String("objdump_tool", "", "tool used to dump a binary")
)
// EscapeReason is an escape reason.
@@ -387,7 +387,7 @@ func loadObjdump() (map[string][]string, error) {
}
// Construct our command.
- cmd := exec.Command(*tool, args...)
+ cmd := exec.Command(*objdumpTool, args...)
cmd.Stdin = stdin
cmd.Stderr = os.Stderr
out, err := cmd.StdoutPipe()